#ifndef _TEST_H_
#define _TEST_H_


#include <tqstring.h>
#include <tqstringlist.h>


#include <dcopobject.h>
#include <dcopref.h>


class test : virtual public DCOPObject
{
  K_DCOP

public:

k_dcop:

  virtual void noArg() = 0;
  virtual ASYNC asyncNoArg() = 0;

  virtual void oneArg(bool val) = 0;
  virtual bool returnFalse() = 0;
  virtual bool returnTrue() = 0;

  virtual short shortArg(short in) = 0;
  virtual int intArg(int in) = 0;
  virtual long longArg(long in) = 0;
  
  virtual float floatArg(float in) = 0;
  virtual double doubleArg(double in) = 0;

  virtual TQString stringArg(TQString in) = 0;
  virtual TQStringList stringListArg(TQStringList in) = 0;

  virtual TQCString cstringArg(TQCString in) = 0;

  virtual DCOPRef DCOPRefArg(DCOPRef in) = 0;

};



#endif
